#line 2 "am-scanner.c"

#line 4 "am-scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
    
/* %endif */

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* %endif */

/* %if-not-reentrant */
/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE amp_am_yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE amp_am_yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via amp_am_yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

void amp_am_yyrestart (FILE *input_file ,yyscan_t yyscanner );
void amp_am_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE amp_am_yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void amp_am_yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void amp_am_yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void amp_am_yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void amp_am_yypop_buffer_state (yyscan_t yyscanner );

static void amp_am_yyensure_buffer_stack (yyscan_t yyscanner );
static void amp_am_yy_load_buffer_state (yyscan_t yyscanner );
static void amp_am_yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER amp_am_yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE amp_am_yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE amp_am_yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE amp_am_yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

/* %endif */

void *amp_am_yyalloc (yy_size_t ,yyscan_t yyscanner );
void *amp_am_yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void amp_am_yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer amp_am_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        amp_am_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            amp_am_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        amp_am_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            amp_am_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define amp_am_yywrap(yyscanner) 1
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	yyg->yy_c_buf_p = yy_cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 63
#define YY_END_OF_BUFFER 64
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[321] =
    {   0,
       61,   61,   64,   61,    4,    1,   62,    2,   62,   62,
       61,   61,    9,   11,   13,   61,   62,   61,   61,   61,
       62,   61,   61,   61,   12,   61,   61,   61,    0,    0,
        2,    0,    0,    3,    8,    0,    0,   16,   61,   10,
       14,   15,    0,    5,   61,   61,   61,    2,   17,   20,
       18,   19,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,    2,    0,    0,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   37,   61,    6,    7,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   25,
       61,   61,   61,   33,   61,   61,   61,   61,   61,   28,
       61,   30,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   59,   61,   61,   61,   61,   61,   61,   61,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   33,   61,   61,   61,   61,   61,   61,   23,   50,
       61,   61,   61,   61,   61,   61,   61,   56,   60,   61,
       61,   61,   61,   32,   61,   61,   61,   61,   57,   21,
       22,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   54,   26,   61,   48,   61,
       61,   61,   61,   34,   35,   61,   61,   40,   61,   61,
       61,   61,   61,   46,   61,   61,   47,   61,   49,   51,
       61,   61,   61,   61,   61,   31,   36,   61,   61,   61,
       44,   61,   38,   61,   61,   61,   61,   61,   27,   61,

       55,   53,   39,   41,   61,   61,   61,   61,   61,   52,
       61,   61,   45,   43,   24,   61,   29,   42,   58,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    8,    1,    6,    6,    9,
       10,    1,   11,    1,   12,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,   13,   14,    1,
       15,    1,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,    1,   28,   29,   30,   31,   32,
        1,   33,   34,   35,   36,   37,    1,   38,   39,    1,
        1,   40,    1,    1,   41,    6,    1,    1,   42,   43,

       44,    1,    1,    1,   45,    1,    1,   46,    1,   47,
        1,    1,    1,   48,    1,    1,   49,    1,    1,    1,
        1,    1,   50,   51,   52,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[53] =
    {   0,
        1,    2,    2,    2,    2,    3,    3,    3,    1,    4,
        1,    1,    3,    1,    3,    1,    5,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    6
    } ;

static yyconst flex_int16_t yy_base[327] =
    {   0,
        0,    0,  202,   12,   52,  985,  985,   56,  190,   47,
       45,   21,   52,   27,  985,   57,  154,   40,   48,   35,
       72,   81,   39,   52,   49,   62,    0,   76,  121,  153,
      125,  141,  111,  985,  985,    0,    0,  985,   88,  985,
      985,  985,   94,  985,   93,   99,  106,  136,  985,  985,
      985,  985,  114,  121,  125,  126,  132,  137,  136,  140,
      149,  154,  148,  143,  164,  153,  157,  201,   97,   42,
      167,  191,  180,  183,  184,  188,  194,  199,  204,  210,
      220,  207,  231,  215,  236,  224,  216,  235,  240,  225,
      247,  246,  253,  256,  257,  110,  260,  985,  985,  261,

      282,  272,  268,  295,  276,  290,  299,  232,  286,  306,
      303,  309,  310,  313,  317,  316,  321,  320,  327,  330,
      347,  334,  341,  335,  352,  355,  356,  348,  359,  360,
      365,  369,  364,  368,  386,  383,  378,  395,  391,  402,
      394,  403,  411,  412,   39,  390,  417,  420,  421,  416,
      426,  429,  443,  430,  447,  433,  442,  454,  459,  437,
      460,  446,  468,  463,  451,  467,  473,  477,  482,  474,
      478,  481,  494,  490,  503,  499,  510,  502,  511,  514,
      518,  521,  527,  507,  526,  531,  538,  544,  547,  543,
      550,  534,  554,  555,  559,  566,  570,  573,  565,  574,

      577,  583,  587,  591,  588,  592,  597,  603,  611,  615,
      607,  625,  629,  633,  626,  630,  636,  640,  551,  580,
      637,  641,  653,  621,  652,  657,  656,  646,  660,  665,
      670,  674,  673,  664,  678,  684,  679,  691,  683,  687,
      688,  699,  705,  717,  712,  716,  713,  704,  721,  722,
      727,  730,  733,  738,  739,  700,  734,  748,  742,  756,
      751,  762,  759,  747,  755,  767,  763,  766,  771,  787,
      779,  788,  783,  778,  797,  800,  782,  801,  791,  792,
      816,  813,  805,  819,  824,  806,  809,  827,  830,  835,
      810,  845,  831,  842,  851,  846,  854,  850,  855,  859,

      858,  862,  863,  866,  884,  876,  877,  880,  890,  872,
      894,  895,  881,  889,  898,  906,  901,  902,  905,  985,
      949,  955,  961,  967,  973,  979
    } ;

static yyconst flex_int16_t yy_def[327] =
    {   0,
      320,    1,  320,  321,  320,  320,  320,  320,  322,  323,
      321,  321,  320,  321,  320,  321,  324,  321,  321,  321,
      320,  321,  321,  321,  321,  321,   22,  321,  320,  322,
      320,  320,  322,  320,  320,  325,  326,  320,  321,  320,
      320,  320,  324,  320,  321,  321,  321,  320,  320,  320,
      320,  320,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  320,  325,  326,
      321,   22,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  320,  320,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,   22,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,

      321,  321,  321,  321,  321,  321,  321,  321,  321,  321,
      321,  321,  321,  321,  321,  321,  321,  321,  321,    0,
      320,  320,  320,  320,  320,  320
    } ;

static yyconst flex_int16_t yy_nxt[1038] =
    {   0,
        4,    5,    6,    7,    8,    7,    9,   10,    4,    4,
       11,   12,   13,   14,   15,   16,   17,   18,    4,    4,
       19,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,   20,    4,    4,    4,    4,    4,   21,
       22,    4,   23,    4,   24,    4,    4,    4,    4,    4,
       25,    4,   27,   29,   28,   36,   29,   31,   30,   38,
       31,   27,   30,   28,   40,   39,   41,   27,   45,   28,
       47,   42,  183,   46,   48,   27,   49,   28,   50,   27,
       27,   28,   28,   66,   51,   27,   52,   28,   27,   27,
       28,   28,   27,   99,   28,   32,   37,   27,   67,   28,

       53,   54,   27,   55,   28,   56,   98,   57,   58,   59,
       44,   60,   61,   34,   62,   63,   27,   64,   28,   65,
       66,   27,   29,   28,   74,   29,   31,   30,   27,   31,
       28,   30,   73,   72,   71,   28,   75,   68,   78,   27,
       68,   28,   79,   68,   80,   76,   27,   81,   28,   82,
       27,   77,   28,   87,   27,   34,   28,   83,   88,   84,
       94,   27,   85,   28,   32,   27,   27,   28,   28,   93,
       44,   86,   27,   91,   28,   32,   27,   27,   28,   28,
       27,   89,   28,   27,   92,   28,   95,   90,   27,   27,
       28,   28,   34,   27,   27,   28,   28,   27,   97,   28,

       96,  320,   68,  109,   27,   68,   28,   27,  100,   28,
      101,  110,  320,  102,  108,  320,  320,  103,  104,  111,
       27,  105,   28,   27,   27,   28,   28,  106,   27,  107,
       28,  112,  115,  113,   27,  114,   28,  116,  320,   27,
       32,   28,  120,  117,   27,  124,   28,   27,  118,   28,
       27,  123,   28,  119,  121,   27,   27,   28,   28,  127,
       27,  125,   28,  320,   27,   27,   28,   28,  320,  122,
      126,   27,  145,   28,   28,   27,   27,   28,   28,  128,
       27,  129,   28,  131,  132,  139,   27,   27,   28,   28,
      130,  138,  320,   27,  142,   28,   27,   27,   28,   28,

       27,   27,   28,   28,  135,  133,  134,  143,   27,  320,
       28,  146,   27,  136,   28,  140,   27,  141,   28,  137,
       85,  144,   27,  147,   28,  148,   27,  150,   28,   86,
       27,  149,   28,  320,  151,   27,  153,   28,  154,   27,
      155,   28,  320,   27,  152,   28,   27,  157,   28,   27,
       27,   28,   28,   27,  156,   28,   27,   27,   28,   28,
       27,   27,   28,   28,  158,  160,  161,   27,  162,   28,
       27,  163,   28,  166,   27,   27,   28,   28,  164,  159,
      165,   27,  169,   28,  320,  168,  170,   27,   27,   28,
       28,  167,   27,  320,   28,   27,   27,   28,   28,   27,

       27,   28,   28,  320,   27,   27,   28,   28,   27,   27,
       28,   28,  171,  173,  174,  175,  172,  176,   27,  118,
       28,  179,  184,   27,  178,   28,   27,  177,   28,  180,
       27,   27,   28,   28,   27,   27,   28,   28,  181,  182,
      185,  320,   27,   27,   28,   28,  189,  186,  187,  191,
      193,   27,   27,   28,   28,  188,   27,   27,   28,   28,
       27,   27,   28,   28,  190,  194,   27,  192,   28,   27,
       27,   28,   28,   27,  195,   28,  196,   27,  197,   28,
      320,  200,   27,   27,   28,   28,   27,   27,   28,   28,
      198,   27,  202,   28,   27,  199,   28,  205,  201,   27,

       27,   28,   28,   27,  204,   28,  203,   27,   27,   28,
       28,  208,  209,   27,   27,   28,   28,   27,   27,   28,
      206,   27,   27,  207,   28,  210,  211,  212,  214,  213,
       27,  320,   28,  215,   27,  216,   28,  320,  217,   27,
      219,   28,   27,   27,   28,   28,   91,   27,  221,   28,
       27,   27,   28,   28,   27,  222,   28,   92,   27,  220,
       28,   27,  218,   28,  223,  320,   27,   27,   28,   28,
      224,   27,  226,   28,   27,  225,   28,  227,   27,  229,
       28,  320,  233,   27,   27,   28,   28,   27,  228,   28,
       27,   27,   28,   28,   27,   27,   28,   28,  230,   27,

      232,   28,  231,  234,  236,   27,   27,   28,   28,  237,
       27,  235,   28,   27,   27,   28,   28,   27,  238,   28,
       27,  239,   28,   27,  245,   28,  242,   27,   27,   28,
       28,   27,   27,   28,   28,  240,   66,   27,  243,   28,
      241,   66,  244,   27,  246,   28,  247,   27,  249,   28,
      320,   27,  250,   28,  256,   27,  248,   28,  252,  251,
      253,   27,  320,   28,  254,   27,   27,   28,   28,   27,
       27,   28,   28,   27,  255,   28,   27,   27,   28,   28,
       27,   27,   28,   28,  258,  257,   27,  261,   28,  259,
      260,  262,   27,   27,   28,   28,   27,   27,   28,   28,

       27,  263,   28,  320,   27,   27,   28,   28,  267,  266,
       27,  264,   28,   27,   27,   28,   28,  265,   27,   27,
       28,   28,  269,   27,   27,   28,   28,   27,   27,   28,
       28,   27,  268,   28,  270,  271,  273,  274,  272,   27,
       27,   28,   28,  320,   27,   27,   28,   28,  275,  276,
      278,  320,   27,   27,   28,   28,   27,   27,   28,   28,
      277,   27,   27,   28,   28,  282,  279,   27,  281,   28,
       27,  280,   28,   27,   27,   28,   28,  283,   27,   27,
       28,   28,   27,  284,   28,  285,  288,   27,   27,   28,
       28,   27,  286,   28,  289,   27,   27,   28,   28,   27,

      287,   28,   27,   27,   28,   28,   27,   27,   28,   28,
      290,   27,  291,   28,  294,  292,  293,  295,   27,   27,
       28,   28,   27,   27,   28,   28,  296,   27,   27,   28,
       28,   27,   27,   28,   28,  297,  298,   27,  299,   28,
       27,   27,   28,   28,  300,   27,   27,   28,   28,   27,
       27,   28,   28,   27,  320,   28,   27,  301,   28,   27,
      302,   28,  305,  303,   27,  306,   28,   27,  304,   28,
       27,   27,   28,   28,  307,   27,  320,   28,  308,  309,
      311,  320,   27,  310,   28,   27,   27,   28,   28,  320,
       27,   27,   28,   28,   27,   27,   28,   28,   27,   27,

       28,   28,   27,   27,   28,   28,   27,  312,   28,  313,
      314,  316,   27,  315,   28,  320,   27,   27,   28,   28,
       27,   27,   28,   28,   27,  320,   28,  317,  318,   27,
       27,   28,   28,  320,   27,   27,   28,   28,   27,  319,
       28,   27,   27,   28,   28,   27,   27,   28,   28,   26,
      320,  320,   26,  320,   26,   33,   33,   33,   33,   33,
       33,   35,  320,   35,   35,   35,   35,   43,  320,  320,
       43,   43,   43,   69,   69,   69,  320,   69,   69,   70,
       70,   70,   70,   70,    3,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,

      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320
    } ;

static yyconst flex_int16_t yy_chk[1038] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    4,    5,    4,   10,    5,    8,    5,   11,
        8,   12,    8,   12,   13,   12,   13,   14,   18,   14,
       20,   16,  145,   19,   21,   20,   21,   20,   21,   23,
       18,   23,   18,   23,   21,   11,   21,   11,   19,   25,
       19,   25,   24,   70,   24,    8,   10,   16,   24,   16,

       22,   22,   26,   22,   26,   22,   69,   22,   22,   22,
       43,   22,   22,   33,   22,   22,   28,   22,   28,   22,
       28,   22,   29,   22,   47,   29,   31,   29,   39,   31,
       39,   31,   46,   45,   39,   45,   53,   48,   54,   46,
       48,   46,   54,   32,   55,   53,   47,   56,   47,   57,
       96,   53,   96,   59,   53,   30,   53,   58,   60,   58,
       64,   54,   58,   54,   31,   55,   56,   55,   56,   63,
       17,   58,   57,   62,   57,   48,   59,   58,   59,   58,
       60,   61,   60,   64,   62,   64,   65,   61,   63,   61,
       63,   61,    9,   66,   62,   66,   62,   67,   67,   67,

       66,    3,   68,   74,   65,   68,   65,   71,   71,   71,
       72,   75,    0,   72,   73,    0,    0,   72,   72,   76,
       73,   72,   73,   74,   75,   74,   75,   72,   76,   72,
       76,   77,   80,   78,   77,   79,   77,   81,    0,   78,
       68,   78,   84,   82,   79,   87,   79,   82,   83,   82,
       80,   86,   80,   83,   85,   84,   87,   84,   87,   90,
       81,   88,   81,    0,   86,   90,   86,   90,    0,   85,
       89,   83,  108,   83,  108,   88,   85,   88,   85,   91,
       89,   92,   89,   94,   95,  103,   92,   91,   92,   91,
       93,  102,    0,   93,  105,   93,   94,   95,   94,   95,

       97,  100,   97,  100,  101,   97,  100,  106,  103,    0,
      103,  109,  102,  101,  102,  104,  105,  104,  105,  101,
      104,  107,  101,  110,  101,  111,  109,  113,  109,  104,
      106,  112,  106,    0,  114,  104,  116,  104,  117,  107,
      118,  107,    0,  111,  115,  111,  110,  120,  110,  112,
      113,  112,  113,  114,  119,  114,  116,  115,  116,  115,
      118,  117,  118,  117,  121,  122,  123,  119,  124,  119,
      120,  125,  120,  128,  122,  124,  122,  124,  126,  121,
      127,  123,  131,  123,    0,  130,  132,  121,  128,  121,
      128,  129,  125,    0,  125,  126,  127,  126,  127,  129,

      130,  129,  130,    0,  133,  131,  133,  131,  134,  132,
      134,  132,  133,  135,  136,  137,  134,  138,  137,  140,
      137,  141,  146,  136,  140,  136,  135,  139,  135,  142,
      146,  139,  146,  139,  141,  138,  141,  138,  143,  144,
      147,    0,  140,  142,  140,  142,  152,  148,  149,  154,
      156,  143,  144,  143,  144,  151,  150,  147,  150,  147,
      148,  149,  148,  149,  153,  157,  151,  155,  151,  152,
      154,  152,  154,  156,  158,  156,  159,  160,  161,  160,
        0,  165,  157,  153,  157,  153,  162,  155,  162,  155,
      163,  165,  167,  165,  158,  164,  158,  170,  166,  159,

      161,  159,  161,  164,  169,  164,  168,  166,  163,  166,
      163,  173,  174,  167,  170,  167,  170,  168,  171,  168,
      171,  172,  169,  172,  169,  175,  176,  177,  179,  178,
      174,    0,  174,  180,  173,  181,  173,    0,  182,  176,
      184,  176,  178,  175,  178,  175,  183,  184,  186,  184,
      177,  179,  177,  179,  180,  187,  180,  183,  181,  185,
      181,  182,  183,  182,  188,    0,  185,  183,  185,  183,
      189,  186,  191,  186,  192,  190,  192,  193,  187,  195,
      187,    0,  199,  190,  188,  190,  188,  189,  194,  189,
      191,  219,  191,  219,  193,  194,  193,  194,  196,  195,

      198,  195,  197,  200,  202,  199,  196,  199,  196,  203,
      197,  201,  197,  198,  200,  198,  200,  201,  204,  201,
      220,  205,  220,  202,  211,  202,  208,  203,  205,  203,
      205,  204,  206,  204,  206,  206,  206,  207,  209,  207,
      207,  207,  210,  208,  212,  208,  213,  211,  215,  211,
        0,  209,  216,  209,  224,  210,  214,  210,  218,  217,
      221,  224,    0,  224,  222,  212,  215,  212,  215,  213,
      216,  213,  216,  214,  223,  214,  217,  221,  217,  221,
      218,  222,  218,  222,  226,  225,  228,  231,  228,  227,
      230,  232,  225,  223,  225,  223,  227,  226,  227,  226,

      229,  233,  229,    0,  234,  230,  234,  230,  238,  237,
      231,  235,  231,  233,  232,  233,  232,  236,  235,  237,
      235,  237,  243,  239,  236,  239,  236,  240,  241,  240,
      241,  238,  242,  238,  244,  245,  247,  248,  246,  242,
      256,  242,  256,    0,  248,  243,  248,  243,  249,  250,
      252,    0,  245,  247,  245,  247,  246,  244,  246,  244,
      251,  249,  250,  249,  250,  258,  253,  251,  255,  251,
      252,  254,  252,  253,  257,  253,  257,  260,  254,  255,
      254,  255,  259,  261,  259,  262,  267,  264,  258,  264,
      258,  261,  263,  261,  269,  265,  260,  265,  260,  263,

      266,  263,  262,  267,  262,  267,  268,  266,  268,  266,
      270,  269,  271,  269,  275,  272,  273,  276,  274,  271,
      274,  271,  277,  273,  277,  273,  278,  270,  272,  270,
      272,  279,  280,  279,  280,  281,  282,  275,  283,  275,
      276,  278,  276,  278,  284,  283,  286,  283,  286,  287,
      291,  287,  291,  282,    0,  282,  281,  285,  281,  284,
      288,  284,  292,  289,  285,  294,  285,  288,  290,  288,
      289,  293,  289,  293,  295,  290,    0,  290,  296,  297,
      300,    0,  294,  298,  294,  292,  296,  292,  296,    0,
      298,  295,  298,  295,  297,  299,  297,  299,  301,  300,

      301,  300,  302,  303,  302,  303,  304,  305,  304,  306,
      307,  309,  310,  308,  310,    0,  306,  307,  306,  307,
      308,  313,  308,  313,  305,    0,  305,  311,  312,  314,
      309,  314,  309,    0,  311,  312,  311,  312,  315,  316,
      315,  317,  318,  317,  318,  319,  316,  319,  316,  321,
        0,    0,  321,    0,  321,  322,  322,  322,  322,  322,
      322,  323,    0,  323,  323,  323,  323,  324,    0,    0,
      324,  324,  324,  325,  325,  325,    0,  325,  325,  326,
      326,  326,  326,  326,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,

      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320,  320,  320,  320,
      320,  320,  320,  320,  320,  320,  320
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[64] =
    {   0,
1, 1, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0,     };

static yyconst flex_int16_t yy_rule_linenum[63] =
    {   0,
       99,  101,  103,  105,  107,  109,  111,  113,  115,  117,
      119,  121,  123,  125,  127,  129,  131,  133,  135,  137,
      139,  141,  143,  145,  147,  149,  151,  153,  155,  157,
      159,  161,  163,  165,  167,  169,  171,  173,  175,  177,
      179,  181,  183,  185,  187,  189,  191,  193,  195,  197,
      199,  201,  203,  205,  207,  209,  211,  213,  215,  217,
      219,  221
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "am-scanner.l"
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * am-scanner.l
 * Copyright (C) Sébastien Granjoux 2009 <seb.sfo@free.fr>
 *
 * main.c is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * main.c is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#line 21 "am-scanner.l"

#include "am-scanner.h"
#include "amp-group.h"
#include "am-parser.h"
#include "amp-node.h"
#include "amp-target.h"
#include "amp-source.h"

#include "libanjuta/anjuta-debug.h"
#include "libanjuta/anjuta-token-stream.h"

#include <stdlib.h>
#include <string.h>


#define YY_INPUT(buffer, result, max_size) result = anjuta_token_stream_read (yyextra->stream, buffer, max_size)

#define YY_EXTRA_TYPE  AmpAmScanner*

#define YY_DECL static int am_yylex (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner)

//#define YY_USER_INIT {yy_flex_debug = 1;}

static int amp_am_scanner_parse_end (AmpAmScanner *scanner);

#define RETURN(tok) *yylval = anjuta_token_stream_tokenize (yyextra->stream, tok, yyleng); \
                    return tok

struct _AmpAmScanner
{
	yyscan_t scanner;

	AnjutaTokenStream *stream;

	AmpProject *project;
	AmpGroupNode *group;
	GHashTable *orphan_properties;
	GHashTable *ac_variables;
	GList *am_variables;
	GList *variables;
	gboolean eof;		/* TRUE to emit EOF at the end */
	gboolean expansion;		/* Expand variables */
};

struct _AmpVariableDepend
{
	GList *token;
	GList *depend;
	const gchar *name;
	gboolean evaluated;
};

typedef struct _AmpVariableDepend AmpVariableDepend;


/* Remove some warnings */
#define YY_NO_INPUT 1
#line 961 "am-scanner.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

/* %if-c-only */

static int yy_init_globals (yyscan_t yyscanner );

/* %endif */

/* %if-reentrant */

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int amp_am_yylex_init (yyscan_t* scanner);

int amp_am_yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* %endif */

/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int amp_am_yylex_destroy (yyscan_t yyscanner );

int amp_am_yyget_debug (yyscan_t yyscanner );

void amp_am_yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE amp_am_yyget_extra (yyscan_t yyscanner );

void amp_am_yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *amp_am_yyget_in (yyscan_t yyscanner );

void amp_am_yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *amp_am_yyget_out (yyscan_t yyscanner );

void amp_am_yyset_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t amp_am_yyget_leng (yyscan_t yyscanner );

char *amp_am_yyget_text (yyscan_t yyscanner );

int amp_am_yyget_lineno (yyscan_t yyscanner );

void amp_am_yyset_lineno (int line_number ,yyscan_t yyscanner );

int amp_am_yyget_column  (yyscan_t yyscanner );

void amp_am_yyset_column (int column_no ,yyscan_t yyscanner );

/* %if-bison-bridge */

YYSTYPE * amp_am_yyget_lval (yyscan_t yyscanner );

void amp_am_yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *amp_am_yyget_lloc (yyscan_t yyscanner );
    
        void amp_am_yyset_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int amp_am_yywrap (yyscan_t yyscanner );
#else
extern int amp_am_yywrap (yyscan_t yyscanner );
#endif
#endif

/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int amp_am_yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int amp_am_yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

/* %% [7.0] user's declarations go here */
#line 95 "am-scanner.l"


#line 1272 "am-scanner.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			amp_am_yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				amp_am_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		amp_am_yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 321 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 320 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 63 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 63 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 64 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case YY_STATE_EOF(INITIAL):
#line 97 "am-scanner.l"
{ gint ret = amp_am_scanner_parse_end (yyextra); if (ret !=1) return ret; }
	YY_BREAK
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 99 "am-scanner.l"
{ RETURN (END_OF_LINE); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 101 "am-scanner.l"
{ RETURN (SPACE); }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 103 "am-scanner.l"
{ RETURN (COMMENT); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 105 "am-scanner.l"
{ RETURN (TAB); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 107 "am-scanner.l"
{ RETURN (MACRO); }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 109 "am-scanner.l"
{ RETURN (VARIABLE); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 111 "am-scanner.l"
{ RETURN (VARIABLE); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 113 "am-scanner.l"
{ RETURN (VARIABLE); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 115 "am-scanner.l"
{ RETURN (COLON); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 117 "am-scanner.l"
{ RETURN (DOUBLE_COLON); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 119 "am-scanner.l"
{ RETURN (SEMI_COLON); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 121 "am-scanner.l"
{ RETURN (ORDER); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 123 "am-scanner.l"
{ RETURN (EQUAL); }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 125 "am-scanner.l"
{ RETURN (IMMEDIATE_EQUAL); }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 127 "am-scanner.l"
{ RETURN (CONDITIONAL_EQUAL); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 129 "am-scanner.l"
{ RETURN (APPEND); }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 131 "am-scanner.l"
{ RETURN (CHARACTER); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 133 "am-scanner.l"
{ RETURN (CHARACTER); }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 135 "am-scanner.l"
{ RETURN (CHARACTER); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 137 "am-scanner.l"
{ RETURN (CHARACTER); }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 139 "am-scanner.l"
{ RETURN (INCLUDE); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 141 "am-scanner.l"
{ RETURN (INCLUDE); }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 143 "am-scanner.l"
{ RETURN (SUBDIRS); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 145 "am-scanner.l"
{ RETURN (DIST_SUBDIRS); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 147 "am-scanner.l"
{ RETURN (_DATA); }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 149 "am-scanner.l"
{ RETURN (_HEADERS); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 151 "am-scanner.l"
{ RETURN (_LIBRARIES); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 153 "am-scanner.l"
{ RETURN (_LISP); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 155 "am-scanner.l"
{ RETURN (_LTLIBRARIES); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 157 "am-scanner.l"
{ RETURN (_MANS); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 159 "am-scanner.l"
{ RETURN (_PROGRAMS); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 161 "am-scanner.l"
{ RETURN (_PYTHON); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 163 "am-scanner.l"
{ RETURN (_JAVA); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 165 "am-scanner.l"
{ RETURN (_SCRIPTS); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 167 "am-scanner.l"
{ RETURN (_SOURCES); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 169 "am-scanner.l"
{ RETURN (_TEXINFOS); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 171 "am-scanner.l"
{ RETURN (_DIR); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 173 "am-scanner.l"
{ RETURN (_LDFLAGS);}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 175 "am-scanner.l"
{ RETURN (_CPPFLAGS);}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 177 "am-scanner.l"
{ RETURN (_CFLAGS);}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 179 "am-scanner.l"
{ RETURN (_CXXFLAGS);}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 181 "am-scanner.l"
{ RETURN (_JAVACFLAGS);}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 183 "am-scanner.l"
{ RETURN (_VALAFLAGS);}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 185 "am-scanner.l"
{ RETURN (_FCFLAGS);}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 187 "am-scanner.l"
{ RETURN (_OBJCFLAGS);}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 189 "am-scanner.l"
{ RETURN (_LFLAGS);}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 191 "am-scanner.l"
{ RETURN (_YFLAGS);}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 193 "am-scanner.l"
{ RETURN (TARGET_LDFLAGS);}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 195 "am-scanner.l"
{ RETURN (TARGET_CPPFLAGS);}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 197 "am-scanner.l"
{ RETURN (TARGET_CFLAGS);}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 199 "am-scanner.l"
{ RETURN (TARGET_CXXFLAGS);}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 201 "am-scanner.l"
{ RETURN (TARGET_JAVACFLAGS);}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 203 "am-scanner.l"
{ RETURN (TARGET_VALAFLAGS);}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 205 "am-scanner.l"
{ RETURN (TARGET_FCFLAGS);}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 207 "am-scanner.l"
{ RETURN (TARGET_OBJCFLAGS);}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 209 "am-scanner.l"
{ RETURN (TARGET_LFLAGS);}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 211 "am-scanner.l"
{ RETURN (TARGET_YFLAGS);}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 213 "am-scanner.l"
{ RETURN (TARGET_DEPENDENCIES);}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 215 "am-scanner.l"
{ RETURN (TARGET_LDADD);}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 217 "am-scanner.l"
{ RETURN (TARGET_LIBADD);}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 219 "am-scanner.l"
{ RETURN (NAME); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 221 "am-scanner.l"
{ RETURN (CHARACTER); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 223 "am-scanner.l"
ECHO;
	YY_BREAK
#line 1722 "am-scanner.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * amp_am_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( amp_am_yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of amp_am_yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					amp_am_yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			amp_am_yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) amp_am_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 321 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
/* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 321 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 320);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

/* %if-c-only */

/* %endif */

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					amp_am_yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( amp_am_yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

/* %% [19.0] update BOL and yylineno */
	if ( c == '\n' )
		   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void amp_am_yyrestart  (FILE * input_file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        amp_am_yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            amp_am_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	amp_am_yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	amp_am_yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void amp_am_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		amp_am_yypop_buffer_state();
	 *		amp_am_yypush_buffer_state(new_buffer);
     */
	amp_am_yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	amp_am_yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (amp_am_yywrap()) processing, but the only time this flag
	 * is looked at is after amp_am_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/* %if-c-only */
static void amp_am_yy_load_buffer_state  (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE amp_am_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) amp_am_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in amp_am_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) amp_am_yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in amp_am_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	amp_am_yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with amp_am_yy_create_buffer()
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void amp_am_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		amp_am_yyfree((void *) b->yy_ch_buf ,yyscanner );

	amp_am_yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a amp_am_yyrestart() or at EOF.
 */
/* %if-c-only */
    static void amp_am_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	amp_am_yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then amp_am_yy_init_buffer was _probably_
     * called from amp_am_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void amp_am_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		amp_am_yy_load_buffer_state(yyscanner );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void amp_am_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	amp_am_yyensure_buffer_stack(yyscanner);

	/* This block is copied from amp_am_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from amp_am_yy_switch_to_buffer. */
	amp_am_yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void amp_am_yypop_buffer_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	amp_am_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		amp_am_yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void amp_am_yyensure_buffer_stack (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)amp_am_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in amp_am_yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)amp_am_yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in amp_am_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE amp_am_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) amp_am_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in amp_am_yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	amp_am_yy_switch_to_buffer(b ,yyscanner );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to amp_am_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       amp_am_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE amp_am_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return amp_am_yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to amp_am_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE amp_am_yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) amp_am_yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in amp_am_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = amp_am_yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in amp_am_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE amp_am_yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/* %endif */

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int amp_am_yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int amp_am_yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *amp_am_yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *amp_am_yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t amp_am_yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *amp_am_yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/* %if-reentrant */

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void amp_am_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/* %endif */

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void amp_am_yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "amp_am_yyset_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void amp_am_yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "amp_am_yyset_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see amp_am_yy_switch_to_buffer
 */
void amp_am_yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void amp_am_yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int amp_am_yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void amp_am_yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* %endif */

/* %if-reentrant */
/* Accessor methods for yylval and yylloc */

/* %if-bison-bridge */

YYSTYPE * amp_am_yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void amp_am_yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *amp_am_yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void amp_am_yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* %endif */

/* User-visible API */

/* amp_am_yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int amp_am_yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) amp_am_yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* amp_am_yylex_init_extra has the same functionality as amp_am_yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to amp_am_yyalloc in
 * the yyextra field.
 */

int amp_am_yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    amp_am_yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) amp_am_yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    amp_am_yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from amp_am_yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * amp_am_yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* amp_am_yylex_destroy is for both reentrant and non-reentrant scanners. */
int amp_am_yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		amp_am_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		amp_am_yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	amp_am_yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        amp_am_yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * amp_am_yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

/* %if-reentrant */
    /* Destroy the main struct (reentrant only). */
    amp_am_yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *amp_am_yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *amp_am_yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void amp_am_yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see amp_am_yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 223 "am-scanner.l"



/* Private functions
 *---------------------------------------------------------------------------*/

static void
amp_am_scanner_reparse_token (AmpAmScanner *scanner, AnjutaToken *token, GFile *filename)
{
	AnjutaToken *root;
	AnjutaToken *list;

	if (token == NULL) return;

	token = anjuta_token_concat (token);

	amp_am_yylex_init(&scanner->scanner);
	amp_am_yyset_extra (scanner, scanner->scanner);

	root = anjuta_token_new_static (ANJUTA_TOKEN_FILE, NULL);
	list = amp_am_scanner_parse_token (scanner, root, token, filename, NULL);
	list = anjuta_token_delete_parent (list);
	if (list != NULL) anjuta_token_insert_before (token, list);
	anjuta_token_free (token);
}

/* Private functions, variable dependencies
 *---------------------------------------------------------------------------*/

static AmpVariableDepend *
amp_variable_depend_new (void)
{
	AmpVariableDepend *dep;

	dep = g_new0 (AmpVariableDepend, 1);

	return dep;
}

static void
amp_variable_depend_free (AmpVariableDepend *depend)
{
	g_list_free (depend->token);
	g_list_free (depend->depend);
}

static void
list_depend (AnjutaToken *token, gpointer user_data)
{
	GList **depend = (GList **)user_data;

	if (anjuta_token_get_type (token) == ANJUTA_TOKEN_VARIABLE)
	{
		gchar *string;
		gchar *name;
		guint length;

		string = anjuta_token_evaluate_name(token);
		length = strlen (string);
		if (length > 1)
		{
			if (string[1] == '(')
			{
				string[length - 1] = '\0';
				name = string + 2;
			}
			else
			{
				string[2] = '\0';
				name = string + 1;
			}
			name = g_strdup (name);
			*depend = g_list_prepend (*depend, name);
		}
	}
}

static void
convert_dependencies (gchar *variable_name, AmpVariableDepend *variable, gpointer user_data)
{
	GList *list;
	GHashTable *dependencies = (GHashTable *)user_data;

	variable->token = g_list_reverse (variable->token);

	list = g_list_first (variable->depend);
	if (list == NULL) variable->evaluated = TRUE;
	for (; list != NULL;)
	{
		gchar *name = (gchar *)list->data;
		AmpVariableDepend *depend;
		GList *next;

		depend =g_hash_table_lookup (dependencies, name);
		g_free (name);
		next = g_list_next (list);

		if (depend == NULL)
		{
			/* Unexisting variable, remove it from dependencies */
			variable->depend = g_list_delete_link (variable->depend, list);
		}
		else
		{
			GList *dup;

			/* Look for duplicate */
			for (dup = g_list_first (variable->depend); dup != list; dup = g_list_next (dup))
			{
				if (dup->data == depend) break;
			}

			if (dup == list)
			{
				dup->data = depend;
			}
			else
			{
				/* Find a duplicate */
				variable->depend = g_list_delete_link (variable->depend, list);
			}
		}
		list = next;
	}

}

static GHashTable *
amp_am_scanner_compute_dependencies (AmpAmScanner *scanner)
{
	GHashTable *variable_dependencies;
	GList *variable;

	/* Compute variables dependencies */
	variable_dependencies = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify)g_free, (GDestroyNotify)amp_variable_depend_free);
	for (variable = g_list_first (scanner->variables); variable != NULL; variable = g_list_next (variable))
	{
		AnjutaToken *arg;
		AnjutaToken *value;
		gchar *name;
		GList *list = NULL;
		AmpVariableDepend *depend;

		arg = anjuta_token_first_item ((AnjutaToken *)variable->data);
		name = g_strstrip (anjuta_token_evaluate (arg));

		/* Find variable dependencies data */
		depend =(AmpVariableDepend *)g_hash_table_lookup (variable_dependencies, name);
		if (depend == NULL)
		{
			depend = amp_variable_depend_new ();
			depend->name = name;
			g_hash_table_insert (variable_dependencies, name, depend);
		}

		depend->token = g_list_prepend (depend->token, variable->data);

		/* Find dependencies */
		value = anjuta_token_last_item ((AnjutaToken *)variable->data);
		anjuta_token_foreach_token (value, list_depend, &list);
		depend->depend = g_list_concat (list, depend->depend);
	}

	/* Replace name in dependencies by pointer */
	g_hash_table_foreach (variable_dependencies, (GHFunc)convert_dependencies, variable_dependencies);

	return variable_dependencies;
}

static gint
amp_am_scanner_parse_end (AmpAmScanner *scanner)
{

   	if (scanner->stream == NULL)
   	{
		yyterminate();
	}
   	else
   	{
		if (scanner->eof)
		{
			scanner->eof = FALSE;
			return END_OF_FILE;
		}

		amp_am_yypop_buffer_state(scanner->scanner);
    	scanner->stream = anjuta_token_stream_pop (scanner->stream);

		if (scanner->stream == NULL)
		{
			yyterminate();
		}
		else
		{
			scanner->eof = anjuta_token_stream_get_current_file (scanner->stream) != NULL;

			/* Continue parsing the parent file */
			return 1;
		}
	}
}


/* Parser functions
 *---------------------------------------------------------------------------*/

void
amp_am_yyerror (YYLTYPE *loc, AmpAmScanner *scanner, char const *s)
{
    AnjutaTokenFileLocation location;

    if (amp_project_get_token_location (scanner->project, &location, *loc))
    {
        g_message ("%s:%d.%d %s\n", location.filename, location.line, location.column, s);
        g_free (location.filename);
    }
    else
    {
        g_message ("%s \n", s);
    }
}

void
amp_am_scanner_set_am_variable (AmpAmScanner *scanner, AnjutaToken *variable)
{
	if (!scanner->expansion)
	{
		/* Keep variable token to expand them at the end */
		scanner->am_variables = g_list_prepend (scanner->am_variables, variable);
	}
	else
	{
	    amp_project_set_am_variable (scanner->project, scanner->group, variable, scanner->orphan_properties);
	}
}

void
amp_am_scanner_include (AmpAmScanner *scanner, AnjutaToken *list)
{
	GFile *file;
	AnjutaTokenFile *include;
	AnjutaToken *token;
	AnjutaToken *name;
	gchar *filename;
	AnjutaProjectNode *source;

	name = anjuta_token_first_item (list);
	name = anjuta_token_next_item (name);
	filename = g_strstrip (anjuta_token_evaluate (name));
	//g_message ("read include =%s=", filename);
	file = g_file_resolve_relative_path (anjuta_token_stream_get_current_directory (scanner->stream), filename);
	g_free (filename);
	source = amp_source_node_new (file, ANJUTA_PROJECT_PROJECT | ANJUTA_PROJECT_FRAME | ANJUTA_PROJECT_READ_ONLY);
	anjuta_project_node_append (ANJUTA_PROJECT_NODE (scanner->group), source);
	include = anjuta_token_file_new (file);
	token = anjuta_token_file_load (include, NULL);
	amp_am_scanner_parse_token (scanner, list, token, file, NULL);
	g_object_unref (file);
}

void
amp_am_scanner_update_variable (AmpAmScanner *scanner, AnjutaToken *variable)
{
	if (scanner->expansion == FALSE) scanner->variables = g_list_prepend (scanner->variables, variable);
    amp_group_node_update_variable (scanner->group, variable);
}


void
amp_am_scanner_parse_variable (AmpAmScanner *scanner, AnjutaToken *variable)
{
	guint length;
	gchar *string;
	const gchar *name;
	AnjutaToken *value;

	anjuta_token_set_type (variable, ANJUTA_TOKEN_VARIABLE);

	string = anjuta_token_evaluate(variable);
	length = strlen (string);
	if (string[1] == '(')
	{
		string[length - 1] = '\0';
		name = string + 2;
	}
	else
	{
		string[2] = '\0';
		name = string + 1;
	}
	value = amp_group_node_get_variable_token (scanner->group, name);
	if (value == NULL)
	{
		value = amp_project_get_subst_variable_token (scanner->project, name);
	}

	if (amp_am_scanner_parse_token (scanner, variable, value, NULL, NULL) == NULL)
	{
		/* Recursive variable, display a warning */
		g_warning ("Recursive variable %s. Discard value", name);
	}
	g_free (string);
}

void
amp_am_scanner_parse_ac_variable (AmpAmScanner *scanner, AnjutaToken *variable)
{
	guint length;
	gchar *string;
	const gchar *name;
	AnjutaToken *value;

	anjuta_token_set_type (variable, ANJUTA_TOKEN_VARIABLE);

	string = anjuta_token_evaluate(variable);
	length = strlen (string);
	/* Remove @ surrounding the variable name */
	name = string + 1;
	string[length - 1] = '\0';
	value = amp_project_get_subst_variable_token (scanner->project, name);
	g_free (string);

	if (value != NULL)
	{
		amp_am_scanner_parse_token (scanner, variable, value, NULL, NULL);
	}
}


/* Public functions
 *---------------------------------------------------------------------------*/

AnjutaToken *
amp_am_scanner_parse_token (AmpAmScanner *scanner, AnjutaToken *root, AnjutaToken *content, GFile *filename, GError **error)
{
    AnjutaToken *first;
    AnjutaTokenStream *stream;

    stream = anjuta_token_stream_push (scanner->stream, root, content, filename);
	if (stream == NULL) return NULL;
	
    first = anjuta_token_stream_get_root (stream);

	scanner->eof = filename != NULL;

    if (scanner->stream != NULL)
    {
        /* Parse an included file or a expanded variable */

        scanner->stream = stream;
        amp_am_yypush_buffer_state(amp_am_yy_create_buffer(NULL,YY_BUF_SIZE,scanner->scanner),scanner->scanner);
    }
    else
    {
        amp_am_yypstate *ps;
        gint status;

        scanner->stream = stream;
        ps = amp_am_yypstate_new ();
        do
        {
            YYSTYPE yylval_param;
            YYLTYPE yylloc_param;
            gint yychar = am_yylex (&yylval_param, &yylloc_param, scanner->scanner);

			yylloc_param = yylval_param;
            status = amp_am_yypush_parse (ps, yychar, &yylval_param, &yylloc_param, scanner);

        } while (status == YYPUSH_MORE);
        amp_am_yypstate_delete (ps);

		/* Evaluate autotools variable and needed variables at the end */
		if (scanner->expansion == FALSE)
		{
			GHashTable *variable_dependencies;
			GList *variables;
			GList *var;
			guint evaluated;

			variable_dependencies =amp_am_scanner_compute_dependencies (scanner);
			variables = g_hash_table_get_values (variable_dependencies);

			/* Reevaluate variable having dependencies */
			scanner->expansion = TRUE;
			do
			{
				evaluated = 0;
				for (var =variables; var != NULL;)
				{
					AmpVariableDepend *depend = (AmpVariableDepend *)var->data;
					GList *next;

					next = g_list_next (var);
					if (depend->depend == NULL)
					{
						/* No need to reevaluate */
						variables = g_list_delete_link (variables, var);
					}
					else
					{
						/* Check that all dependencies are evaluated */
						GList*list;
						gboolean missing = FALSE;

						for (list = g_list_first (depend->depend); list != NULL; list = g_list_next (list))
						{
							if (((AmpVariableDepend *)list->data)->evaluated == FALSE)
							{
								missing = TRUE;
								break;
							}
						}
						if (missing == FALSE)
						{
							for (list = g_list_first (depend->token); list != NULL; list = g_list_next (list))
							{
								amp_am_scanner_reparse_token (scanner, (AnjutaToken *)list->data, filename);
							}
							variables = g_list_delete_link (variables, var);
							depend->evaluated = TRUE;
							evaluated++;
						}
					}
					var = next;
				}
			}
			while (evaluated);

			/* The remaining variables have dependencies loop, evaluate them in order */
			if (variables != NULL) DEBUG_PRINT ("Dependencies loop in variables");
			for (var =variables; var != NULL; var = g_list_next (var))
			{
				AmpVariableDepend *depend = (AmpVariableDepend *)var->data;
				GList *list;

				for (list = g_list_first (depend->token); list != NULL; list = g_list_next (list))
				{
					amp_am_scanner_reparse_token (scanner, (AnjutaToken *)list->data, filename);
				}
			}
			g_list_free (variables);
			g_hash_table_destroy (variable_dependencies);

			/* Evaluate autotools variables */
			scanner->am_variables = g_list_reverse (scanner->am_variables);
			for (var = g_list_first (scanner->am_variables); var != NULL; var = g_list_next (var))
			{
				AnjutaToken *token = (AnjutaToken *)var->data;

				amp_am_scanner_reparse_token (scanner, token, filename);
			}
		}
    }

    return first;
}

/* Constructor & Destructor
 *---------------------------------------------------------------------------*/

AmpAmScanner *
amp_am_scanner_new (AmpProject *project, AmpGroupNode *group)
{
	AmpAmScanner *scanner;

	scanner = g_new0 (AmpAmScanner, 1);

	scanner->project = project;
	scanner->group = group;
	scanner->eof = FALSE;

	/* Create hash table for sources list */
	scanner->orphan_properties = g_hash_table_new_full (g_str_hash, g_str_equal, (GDestroyNotify)g_free, (GDestroyNotify)amp_target_node_free);

	/* Create hash table for variable */
	scanner->am_variables = NULL;
	scanner->expansion = FALSE;

	/* Create list of variable */
	scanner->variables = NULL;

    amp_am_yylex_init(&scanner->scanner);
    amp_am_yyset_extra (scanner, scanner->scanner);

	return scanner;
}

void
amp_am_scanner_free (AmpAmScanner *scanner)
{
	g_return_if_fail (scanner != NULL);

    amp_am_yylex_destroy(scanner->scanner);

	/* Free unused sources files */
	g_hash_table_destroy (scanner->orphan_properties);

	g_list_free (scanner->am_variables);

	g_list_free (scanner->variables);

	g_free (scanner);
}

